==> lxqt-policykit_0.14.1.orig.tar.xz: lxqt-policykit-0.14.1/translations/lxqt-policykit-agent_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>LXQtPolicykit::PolicykitAgent</name>
    <message>
        <location filename="../src/policykitagent.cpp" line="71"/>
        <location filename="../src/policykitagent.cpp" line="158"/>
        <source>PolicyKit Information</source>
        <translation>Informasi PolicyKit</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="71"/>
        <source>Another authentization in progress. Please try it again later.</source>
        <translation>Autentikasi lain sedang dalam proses. Silakan coba lagi nanti.</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="139"/>
        <source>Authorization Failed</source>
        <translation>Perizinan gagal</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="139"/>
        <source>Authorization failed for some reason</source>
        <translation>Perizinan gagal karena beberapa alasan</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="153"/>
        <source>PolicyKit Error</source>
        <translation>Kesalahan PolicyKit</translation>
    </message>
</context>
<context>
    <name>PolicykitAgentGUI</name>
    <message>
        <location filename="../src/policykitagentgui.ui" line="14"/>
        <source>Authentication Required</source>
        <translation>Autentikasi Diperlukan</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="55"/>
        <source>Identity:</source>
        <translation>Identitas:</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="65"/>
        <source>Password:</source>
        <translation>Kata sandi:</translation>
    </message>
</context>
</TS>

==> lxqt-policykit_0.15.0.orig.tar.xz: lxqt-policykit-0.15.0/translations/lxqt-policykit-agent_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>LXQtPolicykit::PolicykitAgent</name>
    <message>
        <location filename="../src/policykitagent.cpp" line="75"/>
        <location filename="../src/policykitagent.cpp" line="169"/>
        <source>PolicyKit Information</source>
        <translation>Informasi PolicyKit</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="75"/>
        <source>Another authentication is in progress. Please try again later.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="145"/>
        <source>Authorization Failed</source>
        <translation>Perizinan gagal</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="145"/>
        <source>Authorization failed for some reason</source>
        <translation>Perizinan gagal karena beberapa alasan</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="162"/>
        <source>PolicyKit Error</source>
        <translation>Kesalahan PolicyKit</translation>
    </message>
</context>
<context>
    <name>PolicykitAgentGUI</name>
    <message>
        <location filename="../src/policykitagentgui.ui" line="14"/>
        <source>Authentication Required</source>
        <translation>Autentikasi Diperlukan</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="55"/>
        <source>Identity:</source>
        <translation>Identitas:</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="65"/>
        <source>Password:</source>
        <translation>Kata sandi:</translation>
    </message>
</context>
</TS>
